--- openflow-2012-01-24-3.h	2015-07-23 09:54:17.008479356 -0700
+++ openflow-2012-01-25.h	2015-07-23 09:54:17.012479356 -0700
@@ -1299,76 +1299,76 @@
                                       commands. */
 };
 
-/* Meter property types */
-enum ofp_meter_prop_type {
-    OFPMPT_DROP            = 1,      /* Drop packet. */
-    OFPMPT_DSCP_REMARK     = 2,      /* Remark DSCP in the IP header. */
-    OFPMPT_COLOR_INCREASE  = 3,      /* Increase metering color by amount. */
-    OFPMPT_COLOR_RAISE_TO  = 4,      /* Raise metering color to level. */
-    OFPMPT_EXPERIMENTER    = 0xFFFF  /* Experimenter meter property. */
+/* Meter band types */
+enum ofp_meter_band_type {
+    OFPMBT_DROP            = 1,      /* Drop packet. */
+    OFPMBT_DSCP_REMARK     = 2,      /* Remark DSCP in the IP header. */
+    OFPMBT_COLOR_INCREASE  = 3,      /* Increase metering color by amount. */
+    OFPMBT_COLOR_RAISE_TO  = 4,      /* Raise metering color to level. */
+    OFPMBT_EXPERIMENTER    = 0xFFFF  /* Experimenter meter band. */
 };
 
-/* Common header for all rate properties */
-struct ofp_meter_prop_header {
-    uint16_t        type;    /* One of OFPMPT_*. */
-    uint16_t        len;     /* Length in bytes of this property. */
-    uint32_t        rate;    /* Rate for this property. */
+/* Common header for all meter bands */
+struct ofp_meter_band_header {
+    uint16_t        type;    /* One of OFPMBT_*. */
+    uint16_t        len;     /* Length in bytes of this band. */
+    uint32_t        rate;    /* Rate for this band. */
     uint32_t        burst_size; /* Size of bursts. */
 };
-OFP_ASSERT(sizeof(struct ofp_meter_prop_header) == 12);
+OFP_ASSERT(sizeof(struct ofp_meter_band_header) == 12);
 
-/* OFPMPT_DROP property - drop packets */
-struct ofp_meter_prop_drop {
-    uint16_t        type;    /* OFPMPT_DROP. */
-    uint16_t        len;     /* Length in bytes of this property. */
+/* OFPMBT_DROP band - drop packets */
+struct ofp_meter_band_drop {
+    uint16_t        type;    /* OFPMBT_DROP. */
+    uint16_t        len;     /* Length in bytes of this band. */
     uint32_t        rate;    /* Rate for dropping packets. */
     uint32_t        burst_size; /* Size of bursts. */
     uint8_t         pad[4];
 };
-OFP_ASSERT(sizeof(struct ofp_meter_prop_drop) == 16);
+OFP_ASSERT(sizeof(struct ofp_meter_band_drop) == 16);
 
-/* OFPMPT_DSCP_REMARK property - Remark DSCP in the IP header */
-struct ofp_meter_prop_dscp_remark {
-    uint16_t        type;    /* OFPMPT_DSCP_REMARK. */
-    uint16_t        len;     /* Length in bytes of this property. */
-    uint32_t        rate;    /* Rate for dropping packets. */
+/* OFPMBT_DSCP_REMARK band - Remark DSCP in the IP header */
+struct ofp_meter_band_dscp_remark {
+    uint16_t        type;    /* OFPMBT_DSCP_REMARK. */
+    uint16_t        len;     /* Length in bytes of this band. */
+    uint32_t        rate;    /* Rate for remarking packets. */
     uint32_t        burst_size; /* Size of bursts. */
     uint8_t         prec_level; /* Number of precendence level to substract. */
     uint8_t         pad[3];
 };
-OFP_ASSERT(sizeof(struct ofp_meter_prop_dscp_remark) == 16);
+OFP_ASSERT(sizeof(struct ofp_meter_band_dscp_remark) == 16);
 
-/* OFPMPT_COLOR_INCREASE property - Increase metering color by amount */
-struct ofp_meter_prop_color_increase {
-    uint16_t        type;    /* OFPMPT_COLOR_INCREASE. */
-    uint16_t        len;     /* Length in bytes of this property. */
-    uint32_t        rate;    /* Rate for dropping packets. */
+/* OFPMBT_COLOR_INCREASE band - Increase metering color by amount */
+struct ofp_meter_band_color_increase {
+    uint16_t        type;    /* OFPMBT_COLOR_INCREASE. */
+    uint16_t        len;     /* Length in bytes of this band. */
+    uint32_t        rate;    /* Rate for coloring packets. */
     uint32_t        burst_size; /* Size of bursts. */
     uint32_t        amount;     /* Amount to add to metering color. */
 };
-OFP_ASSERT(sizeof(struct ofp_meter_prop_color_increase) == 16);
+OFP_ASSERT(sizeof(struct ofp_meter_band_color_increase) == 16);
 
-/* OFPMPT_COLOR_RAISE_TO property - Raise metering color to level */
-struct ofp_meter_prop_color_raise_to {
-    uint16_t        type;    /* OFPMPT_COLOR_RAISE_TO. */
-    uint16_t        len;     /* Length in bytes of this property. */
-    uint32_t        rate;    /* Rate for dropping packets. */
+/* OFPMBT_COLOR_RAISE_TO band - Raise metering color to level */
+struct ofp_meter_band_color_raise_to {
+    uint16_t        type;    /* OFPMBT_COLOR_RAISE_TO. */
+    uint16_t        len;     /* Length in bytes of this band. */
+    uint32_t        rate;    /* Rate for coloring packets. */
     uint32_t        burst_size; /* Size of bursts. */
     uint32_t        level;      /* Minimum color level for packet. */
 };
-OFP_ASSERT(sizeof(struct ofp_meter_prop_color_raise_to) == 16);
+OFP_ASSERT(sizeof(struct ofp_meter_band_color_raise_to) == 16);
 
-/* OFPMPT_EXPERIMENTER property - Write actions in action set */
-struct ofp_meter_prop_experimenter {
-    uint16_t        type;    /* One of OFPMPT_*. */
-    uint16_t        len;     /* Length in bytes of this property. */
-    uint32_t        rate;    /* Rate for dropping packets. */
+/* OFPMBT_EXPERIMENTER band - Write actions in action set */
+struct ofp_meter_band_experimenter {
+    uint16_t        type;    /* One of OFPMBT_*. */
+    uint16_t        len;     /* Length in bytes of this band. */
+    uint32_t        rate;    /* Rate for this band. */
     uint32_t        burst_size;   /* Size of bursts. */
     uint32_t        experimenter; /* Experimenter ID which takes the same
                                      form as in struct
                                      ofp_experimenter_header. */
 };
-OFP_ASSERT(sizeof(struct ofp_meter_prop_experimenter) == 16);
+OFP_ASSERT(sizeof(struct ofp_meter_band_experimenter) == 16);
 
 /* Meter commands */
 enum ofp_meter_mod_command {
@@ -1391,7 +1391,7 @@
     uint16_t            command;        /* One of OFPMC_*. */
     uint16_t            flags;          /* One of OFPMF_*. */
     uint32_t            meter_id;       /* Meter instance. */
-    struct ofp_meter_prop_header properties[0]; /* The properties length is
+    struct ofp_meter_band_header bands[0]; /* The bands length is
                                            inferred from the length field
                                            in the header. */
 };
@@ -1612,11 +1612,11 @@
     OFPMMFC_BAD_FLAGS     = 5,  /* Flag configuration unsupported. */
     OFPMMFC_BAD_RATE      = 6,  /* Rate unsupported. */
     OFPMMFC_BAD_BURST     = 7,  /* Burst size unsupported. */
-    OFPMMFC_BAD_PROPERTY  = 8,  /* Property unsupported. */
-    OFPMMFC_BAD_PROP_VALUE = 9, /* Property value unsupported. */
+    OFPMMFC_BAD_BAND      = 8,  /* Band unsupported. */
+    OFPMMFC_BAD_BAND_VALUE = 9, /* Band value unsupported. */
     OFPGMFC_OUT_OF_METERS  = 10, /* No more meters available. */
-    OFPGMFC_OUT_OF_PROPERTIES = 11,  /* The maximum number of properties
-                                      * for a meter has been exceeded. */
+    OFPGMFC_OUT_OF_BANDS  = 11, /* The maximum number of properties
+                                 * for a meter has been exceeded. */
 };
 
 /* OFPT_ERROR: Error message (datapath -> controller). */
@@ -1945,12 +1945,12 @@
 };
 OFP_ASSERT(sizeof(struct ofp_meter_stats_request) == 8);
 
-/* Statistics for each meter properties */
-struct ofp_meter_prop_stats {
-    uint64_t        packet_over_count;   /* Number of packets exceed prop. */
-    uint64_t        byte_over_count;     /* Number of bytes exceed prop. */
+/* Statistics for each meter band */
+struct ofp_meter_band_stats {
+    uint64_t        packet_band_count;   /* Number of packets in band. */
+    uint64_t        byte_band_count;     /* Number of bytes in band. */
 };
-OFP_ASSERT(sizeof(struct ofp_meter_prop_stats) == 16);
+OFP_ASSERT(sizeof(struct ofp_meter_band_stats) == 16);
 
 /* Body of reply to OFPST_METER request. Meter statistics. */
 struct ofp_meter_stats {
@@ -1960,7 +1960,7 @@
     uint32_t        flow_count;       /* Number of flows bound to meter. */
     uint64_t        packet_in_count;  /* Number of packets in input. */
     uint64_t        byte_in_count;    /* Number of bytes in input. */
-    struct ofp_meter_prop_stats prop_stats[0]; /* The properties length is
+    struct ofp_meter_band_stats band_stats[0]; /* The band_stats length is
                                          inferred from the length field. */
 };
 OFP_ASSERT(sizeof(struct ofp_meter_stats) == 32);
@@ -1970,7 +1970,7 @@
     uint16_t        length;           /* Length of this entry. */
     uint16_t        flags;            /* All OFPMC_* that apply. */
     uint32_t        meter_id;         /* Meter instance. */
-    struct ofp_meter_prop_header properties[0]; /* The properties length is
+    struct ofp_meter_band_header bands[0]; /* The bands length is
 					 inferred from the length field. */
 };
 OFP_ASSERT(sizeof(struct ofp_meter_config_stats) == 8);
@@ -1978,7 +1978,7 @@
 /* Body of reply to OFPST_METER_FEATURES request. Meter features. */
 struct ofp_meter_features_stats {
     uint32_t    max_meter;    /* Maximum number of meters. */
-    uint32_t    types;        /* Bitmaps of OFPMPT_* values supported. */
+    uint32_t    band_types;   /* Bitmaps of OFPMBT_* values supported. */
     uint32_t    capabilities; /* Bitmaps of "ofp_meter_flags". */
     uint8_t     pad[4];
 };
